if(!self.define){let e,i={};const s=(s,n)=>(s=new URL(s+".js",n).href,i[s]||new Promise(i=>{if("document"in self){const e=document.createElement("script");e.src=s,e.onload=i,document.head.appendChild(e)}else e=s,importScripts(s),i()}).then(()=>{let e=i[s];if(!e)throw new Error(`Module ${s} didn’t register its module`);return e}));self.define=(n,r)=>{const t=e||("document"in self?document.currentScript.src:"")||location.href;if(i[t])return;let o={};const l=e=>s(e,t),f={module:{uri:t},exports:o,require:l};i[t]=Promise.all(n.map(e=>f[e]||l(e))).then(e=>(r(...e),o))}}define(["./workbox-8c29f6e4"],function(e){"use strict";self.skipWaiting(),e.clientsClaim(),e.precacheAndRoute([{url:"ws-test.html",revision:"def76ee9f022847f9bffec8689aa64b0"},{url:"registerSW.js",revision:"402b66900e731ca748771b6fc5e7a068"},{url:"index.html",revision:"b9965af75b68a5a71bfe12f229ccd51e"},{url:"assets/main-w_YFpwlT.css",revision:null},{url:"assets/main-CxHf7hM3.js",revision:null},{url:"apple-touch-icon.png",revision:"44db7a22f4fd4d1bf19abbd68b731a07"},{url:"manifest.webmanifest",revision:"f69a01b0bb8e5290e4b3b3c0c281e460"}],{}),e.cleanupOutdatedCaches(),e.registerRoute(new e.NavigationRoute(e.createHandlerBoundToURL("index.html")))});
